@@ -12,9 +12,17 @@
 #if !defined(APT_STRINGVIEW_H)
 #define APT_STRINGVIEW_H
 #include <apt-pkg/macros.h>
+#include <algorithm>
 #include <cstring>
+#include <iosfwd>
 #include <string>
+#include <string_view>
 
+#if APT_PKG_ABI > 600
+namespace APT {
+using StringView = std::string_view;
+}
+#else
 namespace APT {
 
 /**
@@ -146,17 +154,6 @@ inline std::ostream& operator<<(std::ostream& os, const StringView& sv)
     return os << static_cast<std::string_view>(sv);
 }
 
-/**
- * \brief Faster comparison for string views (compare size before data)
- *
- * Still stable, but faster than the normal ordering. */
-static inline int StringViewCompareFast(const std::string_view & a, const std::string_view & b) {
-    if (a.size() != b.size())
-        return a.size() - b.size();
-
-    return a.compare(b);
-}
-
 static constexpr inline APT::StringView operator""_sv(const char *data, size_t size)
 {
    return APT::StringView(data, size);
@@ -168,5 +165,6 @@ inline bool operator ==(const char *other, APT::StringView that) { return that.o
 template<class = void> bool operator ==(std::string_view const &other, APT::StringView const &that) { return that.operator==(other); }
 template<class = void> bool operator !=(std::string_view const &other, APT::StringView const &that) { return that.operator!=(other); }
 template<class = void> bool operator !=(APT::StringView const &that, std::string_view const &other) { return that.operator!=(other); }
+#endif
 
 #endif
