@@ -21,23 +21,25 @@
 #include <apt-pkg/hashes.h>
 #include <apt-pkg/strutl.h>
 
+#include <array>
+#include <cstring>
 #include <string>
 #include <vector>
-#include <string.h>
 #include <sys/stat.h>
 #include <sys/time.h>
 
 #include <apti18n.h>
 									/*}}}*/
 
-class StoreMethod : public aptMethod
+class StoreMethod final : public aptMethod
 {
-   virtual bool Fetch(FetchItem *Itm) APT_OVERRIDE;
+   bool Fetch(FetchItem *Itm) override;
 
    public:
 
-   explicit StoreMethod(std::string &&pProg) : aptMethod(std::move(pProg),"1.2",SingleInstance | SendConfig)
+   explicit StoreMethod(std::string &&pProg) : aptMethod(std::move(pProg),"1.2",SingleInstance | SendConfig | SendURIEncoded)
    {
+      SeccompFlags = aptMethod::BASE;
       if (Binary != "store")
 	 methodNames.insert(methodNames.begin(), "store");
    }
@@ -62,8 +64,8 @@ static bool OpenFileWithCompressorByName(FileFd &fileFd, std::string const &File
 									/*}}}*/
 bool StoreMethod::Fetch(FetchItem *Itm)					/*{{{*/
 {
-   URI Get = Itm->Uri;
-   std::string Path = Get.Host + Get.Path; // To account for relative paths
+   URI Get(Itm->Uri);
+   std::string Path = DecodeSendURI(Get.Host + Get.Path); // To account for relative paths
    
    FetchResult Res;
    Res.Filename = Itm->DestFile;
@@ -102,10 +104,10 @@ bool StoreMethod::Fetch(FetchItem *Itm)					/*{{{*/
    Res.Size = 0;
    while (1)
    {
-      unsigned char Buffer[4*1024];
+      std::array<unsigned char, APT_BUFFER_SIZE> Buffer;
       unsigned long long Count = 0;
 
-      if (!From.Read(Buffer,sizeof(Buffer),&Count))
+      if (!From.Read(Buffer.data(),Buffer.size(),&Count))
       {
 	 if (To.IsOpen())
 	    To.OpFail();
@@ -115,8 +117,8 @@ bool StoreMethod::Fetch(FetchItem *Itm)					/*{{{*/
 	 break;
       Res.Size += Count;
 
-      Hash.Add(Buffer,Count);
-      if (To.IsOpen() && To.Write(Buffer,Count) == false)
+      Hash.Add(Buffer.data(),Count);
+      if (To.IsOpen() && To.Write(Buffer.data(),Count) == false)
       {
 	 Failed = true;
 	 break;
